#include "config.h"

#ifdef TARGET_LIBC_PROVIDES_SSP
void __sprintf_chk() {} ;
void __stack_chk_fail() {} ;
#endif

void _Exit() {} ;
void _IO_feof() {} ;
void _IO_getc() {} ;
void _IO_putc() {} ;
void _IO_puts() {} ;
void __assert_fail() {} ;
void __ctype_b_loc() {} ;
void __ctype_get_mb_cur_max() {} ;
void __ctype_tolower_loc() {} ;
void __ctype_toupper_loc() {} ;
void __cxa_atexit() {} ;
void __errno_location() {} ;
void __fpending() {} ;
void __fxstat() {} ;
void __fxstat64() {} ;
void __getpagesize() {} ;
void __getpgid() {} ;
void __h_errno_location() {} ;
void __isinf() {} ;
void __isinff() {} ;
void __isinfl() {} ;
void __isnan() {} ;
void __isnanf() {} ;
void __isnanl() {} ;
void __libc_current_sigrtmax() {} ;
void __libc_current_sigrtmin() {} ;
void __libc_start_main() {} ;
void __lxstat() {} ;
void __lxstat64() {} ;
void __mempcpy() {} ;
void __rawmemchr() {} ;
void __recv_chk() {} ;
void __register_atfork() {} ;
void __sigsetjmp() {} ;
void __stpcpy() {} ;
void __strdup() {} ;
void __strtod_internal() {} ;
void __strtof_internal() {} ;
void __strtok_r() {} ;
void __strtol_internal() {} ;
void __strtold_internal() {} ;
void __strtoll_internal() {} ;
void __strtoul_internal() {} ;
void __strtoull_internal() {} ;
void __sysconf() {} ;
void __sysv_signal() {} ;
void __wcstod_internal() {} ;
void __wcstof_internal() {} ;
void __wcstol_internal() {} ;
void __wcstold_internal() {} ;
void __wcstoul_internal() {} ;
void __xmknod() {} ;
void __xstat() {} ;
void __xstat64() {} ;
void _exit() {} ;
void _longjmp() {} ;
void _setjmp() {} ;
void _tolower() {} ;
void _toupper() {} ;
void a64l() {} ;
void abort() {} ;
void abs() {} ;
void accept() {} ;
void access() {} ;
void acct() {} ;
void adjtime() {} ;
void alarm() {} ;
void asctime() {} ;
void asctime_r() {} ;
void asprintf() {} ;
void atof() {} ;
void atoi() {} ;
void atol() {} ;
void atoll() {} ;
void authnone_create() {} ;
void basename() {} ;
void bcmp() {} ;
void bcopy() {} ;
void bind() {} ;
void bind_textdomain_codeset() {} ;
void bindresvport() {} ;
void bindtextdomain() {} ;
void brk() {} ;
void bsd_signal() {} ;
void bsearch() {} ;
void btowc() {} ;
void bzero() {} ;
void calloc() {} ;
void catclose() {} ;
void catgets() {} ;
void catopen() {} ;
void cfgetispeed() {} ;
void cfgetospeed() {} ;
void cfmakeraw() {} ;
void cfsetispeed() {} ;
void cfsetospeed() {} ;
void cfsetspeed() {} ;
void chdir() {} ;
void chmod() {} ;
void chown() {} ;
void chroot() {} ;
void clearerr() {} ;
void clnt_create() {} ;
void clnt_pcreateerror() {} ;
void clnt_perrno() {} ;
void clnt_perror() {} ;
void clnt_spcreateerror() {} ;
void clnt_sperrno() {} ;
void clnt_sperror() {} ;
void clock() {} ;
void close() {} ;
void closedir() {} ;
void closelog() {} ;
void confstr() {} ;
void connect() {} ;
void creat() {} ;
void creat64() {} ;
void ctermid() {} ;
void ctime() {} ;
void ctime_r() {} ;
void cuserid() {} ;
void daemon() {} ;
void dcgettext() {} ;
void dcngettext() {} ;
void dgettext() {} ;
void difftime() {} ;
void dirfd() {} ;
void dirname() {} ;
void div() {} ;
void dngettext() {} ;
void drand48() {} ;
void dup() {} ;
void dup2() {} ;
void duplocale() {} ;
void ecvt() {} ;
void endgrent() {} ;
void endprotoent() {} ;
void endpwent() {} ;
void endservent() {} ;
void endutent() {} ;
void endutxent() {} ;
void erand48() {} ;
void err() {} ;
void error() {} ;
void errx() {} ;
void execl() {} ;
void execle() {} ;
void execlp() {} ;
void execv() {} ;
void execve() {} ;
void execvp() {} ;
void exit() {} ;
void fchdir() {} ;
void fchmod() {} ;
void fchown() {} ;
void fclose() {} ;
void fcntl() {} ;
void fcvt() {} ;
void fdatasync() {} ;
void fdopen() {} ;
void feof() {} ;
void ferror() {} ;
void fflush() {} ;
void fflush_unlocked() {} ;
void ffs() {} ;
void fgetc() {} ;
void fgetpos() {} ;
void fgetpos64() {} ;
void fgets() {} ;
void fgetwc() {} ;
void fgetwc_unlocked() {} ;
void fgetws() {} ;
void fileno() {} ;
void flock() {} ;
void flockfile() {} ;
void fmtmsg() {} ;
void fnmatch() {} ;
void fopen() {} ;
void fopen64() {} ;
void fork() {} ;
void fpathconf() {} ;
void fprintf() {} ;
void fputc() {} ;
void fputs() {} ;
void fputwc() {} ;
void fputws() {} ;
void fread() {} ;
void free() {} ;
void freeaddrinfo() {} ;
void freelocale() {} ;
void freopen() {} ;
void freopen64() {} ;
void fscanf() {} ;
void fseek() {} ;
void fseeko() {} ;
void fseeko64() {} ;
void fsetpos() {} ;
void fsetpos64() {} ;
void fstatvfs() {} ;
void fstatvfs64() {} ;
void fsync() {} ;
void ftell() {} ;
void ftello() {} ;
void ftello64() {} ;
void ftime() {} ;
void ftok() {} ;
void ftruncate() {} ;
void ftruncate64() {} ;
void ftrylockfile() {} ;
void ftw() {} ;
void ftw64() {} ;
void funlockfile() {} ;
void fwide() {} ;
void fwprintf() {} ;
void fwrite() {} ;
void fwscanf() {} ;
void gai_strerror() {} ;
void gcvt() {} ;
void getaddrinfo() {} ;
void getc() {} ;
void getc_unlocked() {} ;
void getchar() {} ;
void getchar_unlocked() {} ;
void getcontext() {} ;
void getcwd() {} ;
void getdate() {} ;
void getegid() {} ;
void getenv() {} ;
void geteuid() {} ;
void getgid() {} ;
void getgrent() {} ;
void getgrgid() {} ;
void getgrgid_r() {} ;
void getgrnam() {} ;
void getgrnam_r() {} ;
void getgrouplist() {} ;
void getgroups() {} ;
void gethostbyaddr() {} ;
void gethostbyname() {} ;
void gethostid() {} ;
void gethostname() {} ;
void getitimer() {} ;
void getloadavg() {} ;
void getlogin() {} ;
void getlogin_r() {} ;
void getnameinfo() {} ;
void getopt() {} ;
void getopt_long() {} ;
void getopt_long_only() {} ;
void getpagesize() {} ;
void getpeername() {} ;
void getpgid() {} ;
void getpgrp() {} ;
void getpid() {} ;
void getppid() {} ;
void getpriority() {} ;
void getprotobyname() {} ;
void getprotobynumber() {} ;
void getprotoent() {} ;
void getpwent() {} ;
void getpwnam() {} ;
void getpwnam_r() {} ;
void getpwuid() {} ;
void getpwuid_r() {} ;
void getrlimit() {} ;
void getrlimit64() {} ;
void getrusage() {} ;
void getservbyname() {} ;
void getservbyport() {} ;
void getservent() {} ;
void getsid() {} ;
void getsockname() {} ;
void getsockopt() {} ;
void getsubopt() {} ;
void gettext() {} ;
void gettimeofday() {} ;
void getuid() {} ;
void getutent() {} ;
void getutent_r() {} ;
void getutxent() {} ;
void getutxid() {} ;
void getutxline() {} ;
void getw() {} ;
void getwc() {} ;
void getwchar() {} ;
void getwd() {} ;
void glob() {} ;
void glob64() {} ;
void globfree() {} ;
void globfree64() {} ;
void gmtime() {} ;
void gmtime_r() {} ;
void grantpt() {} ;
void hcreate() {} ;
void hdestroy() {} ;
void hsearch() {} ;
void htonl() {} ;
void htons() {} ;
void iconv() {} ;
void iconv_close() {} ;
void iconv_open() {} ;
void if_freenameindex() {} ;
void if_indextoname() {} ;
void if_nameindex() {} ;
void if_nametoindex() {} ;
void imaxabs() {} ;
void imaxdiv() {} ;
void index() {} ;
void inet_addr() {} ;
void inet_ntoa() {} ;
void inet_ntop() {} ;
void inet_pton() {} ;
void initgroups() {} ;
void initstate() {} ;
void insque() {} ;
void ioctl() {} ;
void isalnum() {} ;
void isalpha() {} ;
void isascii() {} ;
void isatty() {} ;
void isblank() {} ;
void iscntrl() {} ;
void isdigit() {} ;
void isgraph() {} ;
void islower() {} ;
void isprint() {} ;
void ispunct() {} ;
void isspace() {} ;
void isupper() {} ;
void iswalnum() {} ;
void iswalpha() {} ;
void iswblank() {} ;
void iswcntrl() {} ;
void iswctype() {} ;
void iswdigit() {} ;
void iswgraph() {} ;
void iswlower() {} ;
void iswprint() {} ;
void iswpunct() {} ;
void iswspace() {} ;
void iswupper() {} ;
void iswxdigit() {} ;
void isxdigit() {} ;
void jrand48() {} ;
void key_decryptsession() {} ;
void kill() {} ;
void killpg() {} ;
void l64a() {} ;
void labs() {} ;
void lchown() {} ;
void lcong48() {} ;
void ldiv() {} ;
void lfind() {} ;
void link() {} ;
void listen() {} ;
void llabs() {} ;
void lldiv() {} ;
void localeconv() {} ;
void localtime() {} ;
void localtime_r() {} ;
void lockf() {} ;
void lockf64() {} ;
void longjmp() {} ;
void lrand48() {} ;
void lsearch() {} ;
void lseek() {} ;
void makecontext() {} ;
void malloc() {} ;
void mblen() {} ;
void mbrlen() {} ;
void mbrtowc() {} ;
void mbsinit() {} ;
void mbsnrtowcs() {} ;
void mbsrtowcs() {} ;
void mbstowcs() {} ;
void mbtowc() {} ;
void memccpy() {} ;
void memchr() {} ;
void memcmp() {} ;
void memcpy() {} ;
void memmem() {} ;
void memmove() {} ;
void memrchr() {} ;
void memset() {} ;
void mkdir() {} ;
void mkfifo() {} ;
void mkstemp() {} ;
void mkstemp64() {} ;
void mktemp() {} ;
void mktime() {} ;
void mlock() {} ;
void mlockall() {} ;
void mmap() {} ;
void mmap64() {} ;
void mprotect() {} ;
void mrand48() {} ;
void msgctl() {} ;
void msgget() {} ;
void msgrcv() {} ;
void msgsnd() {} ;
void msync() {} ;
void munlock() {} ;
void munlockall() {} ;
void munmap() {} ;
void nanosleep() {} ;
void newlocale() {} ;
void nftw() {} ;
void nftw64() {} ;
void ngettext() {} ;
void nice() {} ;
void nl_langinfo() {} ;
void nrand48() {} ;
void ntohl() {} ;
void ntohs() {} ;
void open() {} ;
void opendir() {} ;
void openlog() {} ;
void pathconf() {} ;
void pause() {} ;
void pclose() {} ;
void perror() {} ;
void pipe() {} ;
void pmap_getport() {} ;
void pmap_set() {} ;
void pmap_unset() {} ;
void poll() {} ;
void popen() {} ;
void posix_memalign() {} ;
void posix_openpt() {} ;
void printf() {} ;
void psignal() {} ;
void ptsname() {} ;
void putc() {} ;
void putc_unlocked() {} ;
void putchar() {} ;
void putchar_unlocked() {} ;
void putenv() {} ;
void puts() {} ;
void pututxline() {} ;
void putw() {} ;
void putwc() {} ;
void putwchar() {} ;
void qsort() {} ;
void raise() {} ;
void rand() {} ;
void rand_r() {} ;
void random() {} ;
void read() {} ;
void readdir() {} ;
void readdir64() {} ;
void readdir_r() {} ;
void readlink() {} ;
void readv() {} ;
void realloc() {} ;
void realpath() {} ;
void recv() {} ;
void recvfrom() {} ;
void recvmsg() {} ;
void regcomp() {} ;
void regerror() {} ;
void regexec() {} ;
void regfree() {} ;
void remove() {} ;
void remque() {} ;
void rename() {} ;
void rewind() {} ;
void rewinddir() {} ;
void rindex() {} ;
void rmdir() {} ;
void sbrk() {} ;
void scanf() {} ;
void sched_get_priority_max() {} ;
void sched_get_priority_min() {} ;
void sched_getparam() {} ;
void sched_getscheduler() {} ;
void sched_rr_get_interval() {} ;
void sched_setparam() {} ;
void sched_setscheduler() {} ;
void sched_yield() {} ;
void seed48() {} ;
void seekdir() {} ;
void select() {} ;
void semctl() {} ;
void semget() {} ;
void semop() {} ;
void send() {} ;
void sendmsg() {} ;
void sendto() {} ;
void setbuf() {} ;
void setbuffer() {} ;
void setcontext() {} ;
void setegid() {} ;
void setenv() {} ;
void seteuid() {} ;
void setgid() {} ;
void setgrent() {} ;
void setgroups() {} ;
void sethostname() {} ;
void setitimer() {} ;
void setlocale() {} ;
void setlogmask() {} ;
void setpgid() {} ;
void setpgrp() {} ;
void setpriority() {} ;
void setprotoent() {} ;
void setpwent() {} ;
void setregid() {} ;
void setreuid() {} ;
void setrlimit() {} ;
void setrlimit64() {} ;
void setservent() {} ;
void setsid() {} ;
void setsockopt() {} ;
void setstate() {} ;
void setuid() {} ;
void setutent() {} ;
void setutxent() {} ;
void setvbuf() {} ;
void shmat() {} ;
void shmctl() {} ;
void shmdt() {} ;
void shmget() {} ;
void shutdown() {} ;
void sigaction() {} ;
void sigaddset() {} ;
void sigaltstack() {} ;
void sigandset() {} ;
void sigdelset() {} ;
void sigemptyset() {} ;
void sigfillset() {} ;
void sighold() {} ;
void sigignore() {} ;
void siginterrupt() {} ;
void sigisemptyset() {} ;
void sigismember() {} ;
void siglongjmp() {} ;
void signal() {} ;
void sigorset() {} ;
void sigpause() {} ;
void sigpending() {} ;
void sigprocmask() {} ;
void sigqueue() {} ;
void sigrelse() {} ;
void sigreturn() {} ;
void sigset() {} ;
void sigsuspend() {} ;
void sigtimedwait() {} ;
void sigwait() {} ;
void sigwaitinfo() {} ;
void sleep() {} ;
void snprintf() {} ;
void sockatmark() {} ;
void socket() {} ;
void socketpair() {} ;
void sprintf() {} ;
void srand() {} ;
void srand48() {} ;
void srandom() {} ;
void sscanf() {} ;
void statvfs() {} ;
void statvfs64() {} ;
void stime() {} ;
void stpcpy() {} ;
void stpncpy() {} ;
void strcasecmp() {} ;
void strcasestr() {} ;
void strcat() {} ;
void strchr() {} ;
void strcmp() {} ;
void strcoll() {} ;
void strcpy() {} ;
void strcspn() {} ;
void strdup() {} ;
void strerror() {} ;
void strerror_r() {} ;
void strfmon() {} ;
void strftime() {} ;
void strlen() {} ;
void strncasecmp() {} ;
void strncat() {} ;
void strncmp() {} ;
void strncpy() {} ;
void strndup() {} ;
void strnlen() {} ;
void strpbrk() {} ;
void strptime() {} ;
void strrchr() {} ;
void strsep() {} ;
void strsignal() {} ;
void strspn() {} ;
void strstr() {} ;
void strtod() {} ;
void strtof() {} ;
void strtoimax() {} ;
void strtok() {} ;
void strtok_r() {} ;
void strtol() {} ;
void strtold() {} ;
void strtoll() {} ;
void strtoq() {} ;
void strtoul() {} ;
void strtoull() {} ;
void strtoumax() {} ;
void strtouq() {} ;
void strxfrm() {} ;
void svc_getreqset() {} ;
void svc_register() {} ;
void svc_run() {} ;
void svc_sendreply() {} ;
void svcerr_auth() {} ;
void svcerr_decode() {} ;
void svcerr_noproc() {} ;
void svcerr_noprog() {} ;
void svcerr_progvers() {} ;
void svcerr_systemerr() {} ;
void svcerr_weakauth() {} ;
void svctcp_create() {} ;
void svcudp_create() {} ;
void swab() {} ;
void swapcontext() {} ;
void swprintf() {} ;
void swscanf() {} ;
void symlink() {} ;
void sync() {} ;
void sysconf() {} ;
void syslog() {} ;
void system() {} ;
void tcdrain() {} ;
void tcflow() {} ;
void tcflush() {} ;
void tcgetattr() {} ;
void tcgetpgrp() {} ;
void tcgetsid() {} ;
void tcsendbreak() {} ;
void tcsetattr() {} ;
void tcsetpgrp() {} ;
void tdelete() {} ;
void telldir() {} ;
void tempnam() {} ;
void textdomain() {} ;
void tfind() {} ;
void time() {} ;
void times() {} ;
void tmpfile() {} ;
void tmpfile64() {} ;
void tmpnam() {} ;
void toascii() {} ;
void tolower() {} ;
void toupper() {} ;
void towctrans() {} ;
void towlower() {} ;
void towupper() {} ;
void truncate() {} ;
void truncate64() {} ;
void tsearch() {} ;
void ttyname() {} ;
void ttyname_r() {} ;
void twalk() {} ;
void tzset() {} ;
void ualarm() {} ;
void ulimit() {} ;
void umask() {} ;
void uname() {} ;
void ungetc() {} ;
void ungetwc() {} ;
void unlink() {} ;
void unlockpt() {} ;
void unsetenv() {} ;
void uselocale() {} ;
void usleep() {} ;
void utime() {} ;
void utimes() {} ;
void utmpname() {} ;
void vasprintf() {} ;
void vdprintf() {} ;
void verrx() {} ;
void vfork() {} ;
void vfprintf() {} ;
void vfscanf() {} ;
void vfwprintf() {} ;
void vfwscanf() {} ;
void vprintf() {} ;
void vscanf() {} ;
void vsnprintf() {} ;
void vsprintf() {} ;
void vsscanf() {} ;
void vswprintf() {} ;
void vswscanf() {} ;
void vsyslog() {} ;
void vwprintf() {} ;
void vwscanf() {} ;
void wait() {} ;
void wait4() {} ;
void waitpid() {} ;
void warn() {} ;
void warnx() {} ;
void wcpcpy() {} ;
void wcpncpy() {} ;
void wcrtomb() {} ;
void wcscasecmp() {} ;
void wcscat() {} ;
void wcschr() {} ;
void wcscmp() {} ;
void wcscoll() {} ;
void wcscpy() {} ;
void wcscspn() {} ;
void wcsdup() {} ;
void wcsftime() {} ;
void wcslen() {} ;
void wcsncasecmp() {} ;
void wcsncat() {} ;
void wcsncmp() {} ;
void wcsncpy() {} ;
void wcsnlen() {} ;
void wcsnrtombs() {} ;
void wcspbrk() {} ;
void wcsrchr() {} ;
void wcsrtombs() {} ;
void wcsspn() {} ;
void wcsstr() {} ;
void wcstod() {} ;
void wcstof() {} ;
void wcstoimax() {} ;
void wcstok() {} ;
void wcstol() {} ;
void wcstold() {} ;
void wcstoll() {} ;
void wcstombs() {} ;
void wcstoq() {} ;
void wcstoul() {} ;
void wcstoull() {} ;
void wcstoumax() {} ;
void wcstouq() {} ;
void wcswcs() {} ;
void wcswidth() {} ;
void wcsxfrm() {} ;
void wctob() {} ;
void wctomb() {} ;
void wctrans() {} ;
void wctype() {} ;
void wcwidth() {} ;
void wmemchr() {} ;
void wmemcmp() {} ;
void wmemcpy() {} ;
void wmemmove() {} ;
void wmemset() {} ;
void wordexp() {} ;
void wordfree() {} ;
void wprintf() {} ;
void write() {} ;
void writev() {} ;
void wscanf() {} ;
void xdr_accepted_reply() {} ;
void xdr_array() {} ;
void xdr_bool() {} ;
void xdr_bytes() {} ;
void xdr_callhdr() {} ;
void xdr_callmsg() {} ;
void xdr_char() {} ;
void xdr_double() {} ;
void xdr_enum() {} ;
void xdr_float() {} ;
void xdr_free() {} ;
void xdr_int() {} ;
void xdr_long() {} ;
void xdr_opaque() {} ;
void xdr_opaque_auth() {} ;
void xdr_pointer() {} ;
void xdr_reference() {} ;
void xdr_rejected_reply() {} ;
void xdr_replymsg() {} ;
void xdr_short() {} ;
void xdr_string() {} ;
void xdr_u_char() {} ;
void xdr_u_int() {} ;
void xdr_u_long() {} ;
void xdr_u_short() {} ;
void xdr_union() {} ;
void xdr_vector() {} ;
void xdr_void() {} ;
void xdr_wrapstring() {} ;
void xdrmem_create() {} ;
void xdrrec_create() {} ;
void xdrrec_eof() {} ;
__asm__(".globl __daylight; .pushsection .data; .type __daylight,@object; .size __daylight, 4; __daylight: .long 0; .popsection");
__asm__(".globl __environ; .pushsection .data; .type __environ,@object; .size __environ, 4; __environ: .long 0; .popsection");
__asm__(".globl __timezone; .pushsection .data; .type __timezone,@object; .size __timezone, 4; __timezone: .long 0; .popsection");
__asm__(".globl __tzname; .pushsection .data; .type __tzname,@object; .size __tzname, 8; __tzname: .long 0; .popsection");
__asm__(".weak _environ; _environ = __environ");
__asm__(".comm _nl_msg_cat_cntr,4");
__asm__(".globl _sys_errlist; .pushsection .data; .type _sys_errlist,@object; .size _sys_errlist, 0; _sys_errlist: .long 0; .popsection");
__asm__(".comm _sys_siglist,0");
__asm__(".weak daylight; daylight = __daylight");
__asm__(".weak environ; environ = __environ");
__asm__(".comm getdate_err,4");
__asm__(".comm optarg,4");
__asm__(".comm opterr,4");
__asm__(".comm optind,4");
__asm__(".comm optopt,4");
__asm__(".comm stderr,4");
__asm__(".comm stdin,4");
__asm__(".comm stdout,4");
__asm__(".weak timezone; timezone = __timezone");
__asm__(".weak tzname; tzname = __tzname");
extern const int _IO_stdin_used;
__asm__(".weak _IO_stdin_used;.weak _LSB_IO_stdin_used; _LSB_IO_stdin_used=_IO_stdin_used ");
